{
----------------------------------------------------------
MAS-CompMaker was used to generate this code
MAS-CompMaker, copyright(c) 2000, Mats Asplund / MAs Prod.
----------------------------------------------------------

Component Name: TmTagProducer
        Author: Mats Asplund
      Creation: 2001-07-22
       Version: 1.0
   Description: A component that generates HTML-Formtags. To be used in a WebModule
                or with WebDisPatcher. The Content this component produces
                could easily be added to the DisPatchers ResponseContent.
        Credit:
        E-mail: masprod@telia.com
          Site: http://go.to/masdp
  Legal issues: Copyright (C) 2001 by Mats Asplund


         Usage: This software is provided 'as-is', without any express or
                implied warranty.  In no event will the author be held liable
                for any  damages arising from the use of this software.

                Permission is granted to anyone to use this software for any
                purpose, including commercial applications, and to alter it
                and redistribute it freely, subject to the following
                restrictions:

                1. The origin of this software must not be misrepresented,
                   you must not claim that you wrote the original software.
                   If you use this software in a product, an acknowledgment
                   in the product documentation would be appreciated but is
                   not required.

                2. Altered source versions must be plainly marked as such, and
                   must not be misrepresented as being the original software.

                3. This notice may not be removed or altered from any source
                   distribution.

                4. If you decide to use this software in any of your applications.
                   Send me an EMail and tell me about it.

Quick Reference:
                TmHTMLInput inherits from TComponent.

                Key-Properties:
                  Name:       Name of the component. Used in the HTML-Tag as
                              well.

                  Content:    The resulting HTML-tag.

                  TagType:    Depending of choice, TagType generates HTML for:
                              PushButton, CheckBox, FileUpload, ImageButton,
                              OptionButton, ResetButton, SubmitButton, TextBox,
                              TextArea, DropDownList, ListBox.

                  Value:      HTML-param. used in TagTypes: PushButton,
                              CheckBox, ResetButton, SubmitButton, OptionButton.

                  Checked:    HTML-param. used in TagType: OptionButton.

                  SRC:        HTML-param. used in TagType: ImageButton.
                              The ImageFileName.

                  Rows:       HTML-param. used in TagType: TextArea.

                  Cols:       HTML-param. used in TagType: TextArea.

                  OptionName: HTML-param. used in TagTypes: DropDownList and
                              ListBox.

                  Size:       HTML-param. used in TagType: ListBox and
                              DropDownList (Size always = 1).

--------------------------------------------------------------------------------
}
unit mtagproducer;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls;

type
  TTagType = (mhtPushButton, mhtCheckBox, mhtFileUpload, mhtImageButton,
    mhtOptionButton, mhtResetButton, mhtSubmitButton, mhtTextBox, mhtTextArea,
    mhtDropDownList, mhtListBox);

  TChecked = (mchChecked, mchUnChecked);

  TmTagProducer = class(TComponent)
  private
    fName: TComponentName;
    fTagType: TTagType;
    fValue: string;
    fChecked: TChecked;
    fSRC: TFileName;
    fContent: string;
    fRows: integer;
    fCols: integer;
    fOptionName: string;
    fSize: integer;
    fCopyright: string;
    procedure ChangeContent;
    procedure SetChecked(Value: TChecked);
    procedure SetTagType(Value: TTagType);
    procedure SetSRC(Value: TFileName);
    procedure SetValue(Value: string);
    procedure SetCop(Value: string);
    procedure SetCols(Value: integer);
    procedure SetOptionName(Value: string);
    procedure SetRows(Value: integer);
    procedure SetSize(Value: integer);
  { Private declarations }
  protected
    procedure SetName(const NewName: TComponentName); override;
  public
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  { Private declarations }
  published
    property Name: TComponentName read fName write SetName stored False;
    property Content: string read fContent write fContent;
    property TagType: TTagType read fTagType write SetTagType;
    property Value: string read fValue write SetValue;
    property Checked: TChecked read fChecked write SetChecked;
    property SRC: TFileName read fSRC write SetSRC;
    property Rows: integer read fRows write SetRows;
    property Cols: integer read fCols write SetCols;
    property OptionName: string read fOptionName write SetOptionName;
    property Size: integer read fSize write SetSize;
    property Copyright: string read fCopyright write SetCop;
  { Published declarations }
  end;


procedure Register;

implementation

constructor TmTagProducer.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  fTagType:= mhtTextBox;
  fValue:= 'Value1';
  fChecked:= mchChecked;
  fSRC:= '';
  fRows:= 2;
  fCols:= 20;
  fOptionName:= 'Option1';
  fSize:= 3;
  fCopyright:= 'Copyright (c) 2001, MAs Prod. / Mats Asplund';
end;

destructor TmTagProducer.Destroy;
begin
  inherited Destroy;
end;

procedure TmTagProducer.ChangeContent;
begin
  fContent:= '';
  case fTagType of
    mhtFileUpload:
      fContent:= '<INPUT TYPE="FILE" NAME="' + fName + '">';

    mhtTextBox:
      fContent:= '<INPUT TYPE="TEXT" NAME="' + fName + '">';

    mhtPushButton:
      fContent:= '<INPUT TYPE="BUTTON" NAME="' + fName + '" VALUE="' + fValue + '">';

    mhtCheckBox:
      fContent:= '<INPUT TYPE="CHECKBOX" NAME="' + fName + '" VALUE="' + fValue + '">';

    mhtResetButton:
      fContent:= '<INPUT TYPE="RESET" NAME="' + fName + '" VALUE="' + fValue + '">';

    mhtSubmitButton:
      fContent:= '<INPUT TYPE="SUBMIT" NAME="' + fName + '" VALUE="' + fValue + '">';

    mhtImageButton:
      fContent:= '<INPUT TYPE="IMAGE" NAME="' + fName + '" SRC="' + fSRC + '">';

    mhtOptionButton:
      begin
        fContent:= '<INPUT TYPE="RADIO" NAME="' + fName + '" VALUE="' + fValue + '"';
        if fChecked = mchChecked then
          fContent:= fContent + ' CHECKED="CHECKED">'
        else
          fContent:= fContent + ' CHECKED="UNCHECKED">';
      end;

    mhtTextArea:
      fContent:= '<TEXTAREA NAME="' + fName + '" ROWS="' + IntToStr(fRows) +
        '" COLS="' + IntToStr(fCols) + '"></TEXTAREA>';

    mhtDropDownList:
      fContent:= '<SELECT NAME="' + fName + '" SIZE="1"><OPTION>' +
        fOptionName + '</OPTION></SELECT>';

    mhtListBox:
      fContent:= '<SELECT NAME="' + fName + '" SIZE="' + IntToStr(fSize) +
        '"><OPTION>' + fOptionName + '</OPTION></SELECT>';
  end;
end;

procedure TmTagProducer.SetChecked(Value: TChecked);
begin
  fChecked:= Value;
  ChangeContent;
end;

procedure TmTagProducer.SetCop(Value: string);
begin
  Exit;
end;

procedure TmTagProducer.SetTagType(Value: TTagType);
begin
  fTagType:= Value;
  ChangeContent;
end;

procedure TmTagProducer.SetSRC(Value: TFileName);
begin
  fSRC:= Value;
  ChangeContent;
end;

procedure TmTagProducer.SetValue(Value: string);
begin
  fValue:= Value;
  ChangeContent;
end;

procedure TmTagProducer.SetName(const NewName: TComponentName);
begin
  inherited;
  fName:= NewName;
  ChangeContent;
end;

procedure TmTagProducer.SetCols(Value: integer);
begin
  fCols := Value;
  ChangeContent;
end;

procedure TmTagProducer.SetOptionName(Value: string);
begin
  fOptionName := Value;
  ChangeContent;
end;

procedure TmTagProducer.SetRows(Value: integer);
begin
  fRows := Value;
  ChangeContent;
end;

procedure TmTagProducer.SetSize(Value: integer);
begin
  fSize := Value;
  if fSize < 3 then fSize:= 3;
  ChangeContent;
end;

procedure Register;
begin
  RegisterComponents('MAs Prod.', [TmTagProducer]);
end;

end.

